==> haskell-libbf-0.6.6-87.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-QPXQqnmk7ZClELOXRLMg0
key:                  libBF-0.6.6-QPXQqnmk7ZClELOXRLMg0
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  a37dbfc4c4fa3868fa9e25a14eeb59a4
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-QPXQqnmk7ZClELOXRLMg0
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libbf-0.6.6-88-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 libBF
version:              0.6.6
visibility:           public
id:                   libBF-0.6.6-72Cduw7SzRiAy9JxhoSfMK
key:                  libBF-0.6.6-72Cduw7SzRiAy9JxhoSfMK
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  44bcfd591242d2b71faf5218d35c1abb
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/libBF-0.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-libbf
hs-libraries:         HSlibBF-0.6.6-72Cduw7SzRiAy9JxhoSfMK
extra-libraries:      bf
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD

haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
